Object Detection (objdetect module) {#tutorial_table_of_content_objdetect}
===================================

Ever wondered how your digital camera detects peoples and faces? Look here to find out!

-   @subpage tutorial_cascade_classifier

    *Languages:* C++, Java, Python

    *Compatibility:* \> OpenCV 2.0

    *Author:* Ana Huamán

    Here we learn how to use *objdetect* to find objects in our images or videos

-   @subpage tutorial_traincascade

    This tutorial describes _opencv_traincascade_ application and its parameters.
